@@ -32,14 +32,14 @@
 #' library(caret)
 #'
 #' ########### prepare sample data:
-#' dat <- get(load(system.file("extdata","Cookfarm.RData",package="CAST")))
+#' dat <- readRDS(system.file("extdata","Cookfarm.RDS",package="CAST"))
 #' dat <- aggregate(dat[,c("DEM","TWI", "NDRE.M", "Easting", "Northing")],
 #'   by=list(as.character(dat$SOURCEID)),mean)
 #' pts <- st_as_sf(dat,coords=c("Easting","Northing"))
 #' st_crs(pts) <- 26911
 #' pts_train <- pts[1:29,]
 #' pts_test <- pts[30:42,]
-#' studyArea <- terra::rast(system.file("extdata","predictors_2012-03-25.grd",package="CAST"))
+#' studyArea <- terra::rast(system.file("extdata","predictors_2012-03-25.tif",package="CAST"))
 #' studyArea <- studyArea[[c("DEM","TWI", "NDRE.M", "NDRE.Sd", "Bt")]]
 #'
 #' ########### Distance between training data and new data:
@@ -111,6 +111,9 @@ plot_geodist <- function(x,
                          showPlot=TRUE){
 
 
+  message("plot_geodist() is deprecated and will be removed soon. \n Please use generic plot() function on geodist object from geodist().")
+
+
   # input formatting ------------
   if (inherits(modeldomain, "Raster")) {
 #    if (!requireNamespace("raster", quietly = TRUE))
@@ -247,7 +250,7 @@ sample2prediction = function(x, modeldomain, type, samplesize,variables){
     d0 <- sf::st_distance(modeldomain, x)
     min_d0 <- apply(d0, 1, min)
     sampletoprediction <- data.frame(dist = min_d0,
-                                     what = factor("sample-to-prediction"),
+                                     what = factor("prediction-to-sample"),
                                      dist_type = "geo")
 
   }else if(type == "feature"){
@@ -269,7 +272,7 @@ sample2prediction = function(x, modeldomain, type, samplesize,variables){
       target_dist_feature <- c(target_dist_feature,min(trainDist,na.rm=T))
     }
     sampletoprediction <- data.frame(dist = target_dist_feature,
-                                     what = "sample-to-prediction",
+                                     what = "prediction-to-sample",
                                      dist_type = "feature")
   }
 
@@ -288,7 +291,7 @@ sample2test <- function(x, testdata, type,variables){
     min_d_test <- apply(d_test, 1, min)
 
     dists_test <- data.frame(dist = min_d_test,
-                             what = factor("sample-to-test"),
+                             what = factor("test-to-sample"),
                              dist_type = "geo")
 
 
@@ -311,7 +314,7 @@ sample2test <- function(x, testdata, type,variables){
       test_dist_feature <- c(test_dist_feature,min(testDist,na.rm=T))
     }
     dists_test <- data.frame(dist = test_dist_feature,
-                             what = "sample-to-test",
+                             what = "test-to-sample",
                              dist_type = "feature")
 
 
