@@ -93,6 +93,7 @@ show.nndm = function(x, ...){
 #' @export
 print.knndm <- function(x, ...){
   cat(paste0("knndm object\n",
+             "Space: ", x$space, "\n",
              "Clustering algorithm: ", x$method, "\n",
              "Intermediate clusters (q): ", x$q, "\n",
              "W statistic: ", round(x$W, 4), "\n",
@@ -108,3 +109,34 @@ print.knndm <- function(x, ...){
 show.knndm = function(x, ...){
   print.knndm(x)
 }
+
+
+
+#' @name print
+#' @param x An object of type \emph{ffs}
+#' @param ... other arguments.
+#' @export
+
+
+print.ffs = function(x, ...){
+  cat("Selected Variables: \n")
+  cat(x$selectedvars)
+  cat("\n")
+  cat("---\n")
+  print.train(x)
+}
+
+
+#' @name print
+#' @param x An object of type \emph{ffs}
+#' @param ... other arguments.
+#' @export
+
+show.ffs = function(x, ...){
+  print.ffs(x)
+
+}
+
+
+
+
